@@ -672,4 +672,32 @@ def modify_instance(instance_id: str, payload: dict, token: str) -> Tuple[bool,
             
     except requests.exceptions.RequestException as e:
         return False, f"Network error: {str(e)}", None
-    
\ No newline at end of file
+    
+def get_template_info():
+    """Fetch template information from the API"""
+    try:
+        # Use production endpoint, fallback to localhost for development
+        api_endpoint = f"{BASEURL}/thunder-templates"
+            
+        response = requests.get(api_endpoint, timeout=5)
+        if response.status_code == 200:
+            templates = response.json()
+            
+            # Extract template information
+            names = []
+            nice_names = {}
+            open_ports = {}
+            automount_folders = {}
+            
+            for template_name, template_data in templates.items():
+                names.append(template_name)
+                if 'displayName' in template_data:
+                    nice_names[template_name] = template_data['displayName']
+                if 'openPorts' in template_data:
+                    open_ports[template_name] = template_data['openPorts']
+                if 'automountFolders' in template_data:
+                    automount_folders[template_name] = template_data['automountFolders'][0] if template_data['automountFolders'] else None
+            
+            return names, nice_names, open_ports, automount_folders
+    except Exception as e:
+        raise RuntimeError(f"Failed to fetch template information: {str(e)}")
\ No newline at end of file
